#
# spec file for package tcping
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2022-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tcping
Version:        2.7.1
Release:        1.1
Summary:        A ping program for TCP ports
License:        MIT
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/pouriyajamshidi/tcping
#Git-Clone:     https://github.com/pouriyajamshidi/tcping.git
Source:         https://github.com/pouriyajamshidi/tcping/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.18
BuildRequires:  golang-packaging

%description
TCPing will send TCP probes to an IP address or a hostname specified
by you and prints the result.
It works with both IPv4 and IPv6.

TCPING uses different TCP sequence numbering for successful and
unsuccessful probes, so that when you look at the results and spot
a failed probe, understanding the total packet drops to that point
would be illustrative enough.

 * Monitor your network connection.
 * Determine packet loss.
 * Analyze the network's latency.
 * Show min/avg/max probes latency.
 * Use the -r flag to retry hostname resolution after a predetermined
   number of ping failures. If you want to test your DNS load
   balancing or Global Server Load Balancer (GSLB), you should
   utilize this option..
 * Print connection statistics on Enter key press.
 * Display the longest encountered downtime and uptime duration and
   time.
 * Monitor and audit your peers network.
 * Calculate the total uptime/downtime when conducting a maintenance.
 * An alternative to ping in environments that ICMP is blocked.

%prep
%autosetup -p 1 -a 1

%build
go build -mod=vendor -buildmode=pie -trimpath -o tcping

%install
install -m 755 -D tcping %{buildroot}/%{_bindir}/tcping

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/tcping

%changelog
* Sun Jan 26 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.1
  * bug: fix name resolution in static builds with -4 flag causing
    name resolution failures due to IPv4-mapped IPv6 addresses.
* Sat Jan 18 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.0
  * new feature: implement csv output through --csv <filename> flag
  * new feature: implement plain (color-less) output through
  - -no-color flag.
  * new feature: implement display of source IP address and port
    used to create TCP connections through --show-source-address
    flag.
  * fix: crash on database writes when hostname includes a hyphen.
  * documents: add Chinese translation.
  * tests: add new tests for printProbeSuccess and printProbeFail.
  * tests: add tests for show-local-address flag.
* Sun Oct  6 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.0
  * add -h flag to show help.
  * add -D flag to show time in output lines.
  * Refactor Makefile: Split build section into smaller, distinct
    targets.
  * update flag section of README to include show-failures-only.
  * Refactor/minor cleanups.
  * update Makefile version and tidy go modules.
  * display second instead of seconds on probe failures.
- Update to version 2.5.0
  * new feature: add -show-failures-only flag to omit printing
    successful probes.
  * fix: extra precision for seconds calculation when the value is
    under a second.
  * refactor: migrate to a pure-Go sqlite package.
  * refactor: user flag handlers.
  * cleanup: user input functions.
* Sun Nov 12 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  * new feature: add `-i` to specify the interval between sending
    probes.
  * new feature: add `-I` to specify the source interface to use
    for sending probes.
  * new feature: add `-t` to specify a custom timeout for probes.
  * new feature: add `--db` to specify the path and file name to
    store tcping output to sqlite database. e.g. `--db
    /tmp/tcping.db`.
  * fix: add `rtt` to JSON output
  * refactor: remove unnecessary custom types
  * refactor: memory align `structs`
  * refactor: Debian packaging instructions
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * new feature: add -c or count flag to exit TCPING after a
    certain amount of probes specified by user.
  * fix: packet loss NaN when program terminated too quickly.
  * fix: random IP address selector index out of range bug.
  * fix: display format of IPv4 embedded in IPv6 addresses.
  * fix: time report bug. Everything is now accurate.
  * docs: improve documentation.
- Update to version 1.22.1
  * new feature: implement JSON output.
  * new feature: implement JSON output prettifier.
  * fix IP version selection bug when -4 or -6 flags are passed.
- Update to version 1.21.1
  * make stats struct fields' names uniform.
  * add | separator to summary report for better visibility.
  * fix retry resolve logic.
- Update to version 1.21.0
  * add option to enforce the use of IPv4 -4 or IPv6 -6 addresses
    only.
  * instead of always picking the first, randomly pick an address
    from the list of resolved IP addresses.
- Update to version 1.20.0
  * add hostname, IP and port number to summary output.
* Fri Apr  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.19.2
  * display stats even if all the probes had failed update version
* Sat Mar  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.19.1
  * close TCP connections faster to lessen the resource
    utilization on target.
* Sun Feb 26 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.19.0
  * implmenet sub-millisecond timing report to make it suitable
    for Data center and Cloud environments.
  * fix downtime report miscalculation.
  * misc fixes
* Sat Oct 15 2022 Martin Hauke <mardnh@gmx.de>
- Initial package for tcping, version 1.12.1
